@@ -20,6 +20,16 @@
 
 #include <QDBusInterface>
 
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
 namespace Akregator
 {
 class Application : public KontactInterface::PimUniqueApplication
@@ -67,11 +77,21 @@ int Application::activate(const QStringList &args, const QString &workingDir)
 
 int main(int argc, char **argv)
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     Akregator::Application app(argc, &argv);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("akregator"));
 
     KCrash::initialize();
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+#endif // HAVE_STYLE_MANAGER
 
     app.setDesktopFileName(QStringLiteral("org.kde.akregator"));
     Akregator::AboutData about;
